# 4. Scans
## 4.1. Description
The *AstroPath Pipeline* requires that a number of experimental protocols are understood and followed for the code to work. These protocols include methods for slide scanning, slide naming, reagent tracking, and directory organization. This section of the documentation describes these protocols and provides important definitions for terms used throughout the *AstroPath Pipeline* documentations. Additionally, there is a main directory, referred to as the ```<Mpath>```, which contains a set of csv files. These files contain pertinent information that drives processing such as directory locations, machine names, slide names, and project identifiers. The csv files and methods for adding projects to the pipeline are defined here [4.5](docs/AstroPathProcessingDirectoryandInitializingProjects.md#45-astropath_processing-directory-and-initializing-projects "Title"). To reduce the length of this page, documentation was written into different pages and linked here by a table of contents.

## 4.2. Contents
 - [4.3. Definitions](docs/Definitions.md#43-definitions)
   - [4.3.1. Indentification Definitions](docs/Definitions.md/#431-identification-definitions)
   - [4.3.2. Path Definitions](docs/Definitions.md/#432-path-definitions)
 - [4.4. Scanning Instructions Introduction](docs/ScanningInstructionsIntro.md)
   - [4.4.1. Contents](docs/ScanningInstructionsIntro.md/#441-contents) 
   - [4.4.2. Specimen Table](docs/scanning/SpecimenTable.md#442-specimen_table)
   - [4.4.3. SampleNames (Patient # or M Numbers)](docs/scanning/SampleNames.md)
   - [4.4.4. Control TMA Conventions](docs/scanning/ControlTMAConventions.md)
   - [4.4.5. Whole Slide Scanning Introduction](docs/scanning/WholeSlideScanning.md)
     - [4.4.5.1. Contents](docs/scanning/WholeSlideScanning.md/#4451-contents)
     - [4.4.5.2. Preparing 20% Overlap](docs/scanning/Preparing20Overlap.md)
     - [4.4.5.3. Scan the *Control TMA*](docs/scanning/ScantheControlTMA.md)
     - [4.4.5.4. Scan the Whole Slide Specimens](docs/scanning/ScantheWholeSlideSpecimens.md)
     - [4.4.5.5. Creating a Whole Slide Scanning Plan](docs/scanning/CreatingaWholeSlideScanningPlan.md)
     - [4.4.5.6. Important Scanning Notes](docs/scanning/ImportantScanningNotes.md)
   - [4.4.6. BatchIDs](docs/scanning/BatchIDs.md#446-batchids)
   - [4.4.7. Batch Tables](docs/scanning/BatchTables.md#447-batch-tables)
   - [4.4.8. Merge Configuration Tables](docs/scanning/MergeConfigTables.md)
- [4.5. AstroPath_Processing Directory and Initalizing Projects](docs/AstroPathProcessingDirectoryandInitializingProjects.md#45-astropath_processing-directory-and-initializing-projects)
  - [4.5.1. AstroPath_Processing Directory](docs/AstroPathProcessingDirectoryandInitializingProjects.md/#451-astropath_processing-directory)
  - [4.5.2. Initializing Projects](docs/AstroPathProcessingDirectoryandInitializingProjects.md/#452-initializing-projects)
- [4.6. Directory Organization](docs/DirectoryOrganization.md#46-directory-organization)
  - [4.6.1. Directory Subfolders](docs/DirectoryOrganization.md#461-directory-subfolders)
  - [4.6.2. SlideID Subfolders](docs/DirectoryOrganization.md#462-slideid-subfolders)


